@@ -22,13 +22,13 @@
 #' @export
 expect_length_linter <- function() {
   # TODO(#2465): also catch expect_true(length(x) == 1)
-  xpath <- sprintf("
+  xpath <- "
   following-sibling::expr[
     expr[1][SYMBOL_FUNCTION_CALL[text() = 'length']]
     and (position() = 1 or preceding-sibling::expr[NUM_CONST])
   ]
     /parent::expr[not(SYMBOL_SUB[text() = 'info' or contains(text(), 'label')])]
-  ")
+  "
 
   Linter(linter_level = "expression", function(source_expression) {
     xml_calls <- source_expression$xml_find_function_calls(c("expect_equal", "expect_identical"))
