@@ -19,8 +19,8 @@
 #'   - [lint()] (in case of `lint_dir()` and `lint_package()`; e.g. `linters` or `cache`)
 #' @param cache When logical, toggle caching of lint results. If passed a character string, store the cache in this
 #'   directory.
-#' @param parse_settings Logical, default `TRUE`. Whether to try and parse the [settings][read_settings]. Otherwise,
-#'   the [default_settings()] are used.
+#' @param parse_settings Logical. Whether to try and parse the [settings][read_settings]. Otherwise, the
+#'   [default_settings()] are used. `TRUE` by default when linting files, as opposed to `text=`.
 #' @param text Optional argument for supplying a string or lines directly, e.g. if the file is already in memory or
 #'   linting is being done ad hoc.
 #'
@@ -38,13 +38,19 @@
 #' unlink(f)
 #'
 #' @export
-lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings = TRUE, text = NULL) {
+lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings = !inline_data, text = NULL) {
   # TODO(#2502): Remove this workaround.
   dot_names <- if (getRversion() %in% c("4.1.1", "4.1.2")) names(list(...)) else ...names()
   check_dots(dot_names, c("exclude", "parse_exclusions"))
 
   needs_tempfile <- missing(filename) || re_matches(filename, rex(newline))
   inline_data <- !is.null(text) || needs_tempfile
+
+  if (parse_settings) {
+    read_settings(filename)
+    on.exit(reset_settings(), add = TRUE)
+  }
+
   lines <- get_lines(filename, text)
 
   if (needs_tempfile) {
@@ -58,11 +64,6 @@ lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings =
   filename <- normalize_path(filename, mustWork = !inline_data) # to ensure a unique file in cache
   source_expressions <- get_source_expressions(filename, lines)
 
-  if (isTRUE(parse_settings)) {
-    read_settings(filename)
-    on.exit(reset_settings(), add = TRUE)
-  }
-
   linters <- define_linters(linters)
   linters <- Map(validate_linter_object, linters, names(linters))
 
@@ -75,33 +76,9 @@ lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings =
     return(exclude(lints, lines = lines, linter_names = names(linters), ...))
   }
 
-  file_linter_names <- names(linters)[vapply(linters, is_linter_level, logical(1L), "file")]
-  expression_linter_names <- names(linters)[vapply(linters, is_linter_level, logical(1L), "expression")]
+  lints <- lint_impl_(linters, lint_cache, filename, source_expressions)
 
-  lints <- list()
-  if (!is_tainted(source_expressions$lines)) {
-    for (expr in source_expressions$expressions) {
-      if (is_lint_level(expr, "expression")) {
-        necessary_linters <- expression_linter_names
-      } else {
-        necessary_linters <- file_linter_names
-      }
-      for (linter in necessary_linters) {
-        # use withCallingHandlers for friendlier failures on unexpected linter errors
-        lints[[length(lints) + 1L]] <- withCallingHandlers(
-          get_lints(expr, linter, linters[[linter]], lint_cache, source_expressions$lines),
-          error = function(cond) {
-            cli_abort(
-              "Linter {.fn linter} failed in {.file {filename}}:",
-              parent = cond
-            )
-          }
-        )
-      }
-    }
-  }
-
-  lints <- maybe_append_error_lint(lints, source_expressions$error, lint_cache, filename)
+  lints <- maybe_append_condition_lints(lints, source_expressions, lint_cache, filename)
   lints <- reorder_lints(flatten_lints(lints))
   class(lints) <- c("lints", "list")
 
@@ -114,6 +91,33 @@ lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings =
   zap_temp_filename(res, needs_tempfile)
 }
 
+lint_impl_ <- function(linters, lint_cache, filename, source_expressions) {
+  if (is_tainted(source_expressions$lines)) {
+    return(list())
+  }
+
+  file_linter_names <- names(linters)[vapply(linters, is_linter_level, logical(1L), "file")]
+  expression_linter_names <- names(linters)[vapply(linters, is_linter_level, logical(1L), "expression")]
+
+  lints <- list()
+  for (expr in source_expressions$expressions) {
+    for (linter in necessary_linters(expr, expression_linter_names, file_linter_names)) {
+      # use withCallingHandlers for friendlier failures on unexpected linter errors
+      lints[[length(lints) + 1L]] <- withCallingHandlers(
+        get_lints(expr, linter, linters[[linter]], lint_cache, source_expressions$lines),
+        error = function(cond) {
+          cli_abort(
+            "Linter {.fn linter} failed in {.file {filename}}:",
+            parent = cond
+          )
+        }
+      )
+    }
+  }
+
+  lints
+}
+
 #' @param path For the base directory of the project (for `lint_dir()`) or
 #'   package (for `lint_package()`).
 #' @param relative_path if `TRUE`, file paths are printed using their path relative to the base directory.
@@ -121,9 +125,9 @@ lint <- function(filename, linters = NULL, ..., cache = FALSE, parse_settings =
 #' @param exclusions exclusions for [exclude()], relative to the package path.
 #' @param pattern pattern for files, by default it will take files with any of the extensions
 #' .R, .Rmd, .qmd, .Rnw, .Rhtml, .Rrst, .Rtex, .Rtxt allowing for lowercase r (.r, ...).
-#' @param show_progress Logical controlling whether to show linting progress with a simple text
-#'   progress bar _via_ [utils::txtProgressBar()]. The default behavior is to show progress in
-#'   [interactive()] sessions not running a testthat suite.
+#' @param show_progress Logical controlling whether to show linting progress with
+#'   [cli::cli_progress_along()]. The default behavior is to show progress in [interactive()] sessions
+#'   not running a testthat suite.
 #'
 #' @examples
 #' if (FALSE) {
@@ -186,6 +190,8 @@ lint_dir <- function(path = ".", ...,
   }
 
   if (isTRUE(show_progress)) {
+    # nocov start. Only displays after >=2 seconds;
+    #   we get ample testing interactively, so don't slow down tests just for coverage.
     lints <- lapply(
       # NB: This cli API is experimental (https://github.com/r-lib/cli/issues/709)
       cli::cli_progress_along(files, name = "Running linters"),
@@ -193,6 +199,7 @@ lint_dir <- function(path = ".", ...,
         lint(files[idx], ..., parse_settings = FALSE, exclusions = exclusions)
       }
     )
+    # nocov end
   } else {
     lints <- lapply(
       files,
@@ -347,34 +354,10 @@ validate_linter_object <- function(linter, name) {
   if (is_linter(linter)) {
     return(linter)
   }
-  if (!is.function(linter)) {
-    cli_abort(c(
-      i = "Expected {.fn {name}} to be a function of class {.cls linter}.",
-      x = "Instead, it is {.obj_type_friendly {linter}}."
-    ))
-  }
-  if (is_linter_factory(linter)) {
-    what <- "Passing linters as variables"
-    alternative <- "a call to the linters (see ?linters)"
-  } else {
-    what <- "The use of linters of class 'function'"
-    alternative <- "linters classed as 'linter' (see ?Linter)"
-  }
-  lintr_deprecated(
-    what = what, alternative = alternative, version = "3.0.0",
-    type = "",
-    signal = "stop"
-  )
-}
-
-is_linter_factory <- function(fun) {
-  # A linter factory is a function whose last call is to Linter()
-  bdexpr <- body(fun)
-  # covr internally transforms each call into if (TRUE) { covr::count(...); call }
-  while (is.call(bdexpr) && (bdexpr[[1L]] == "{" || (bdexpr[[1L]] == "if" && bdexpr[[2L]] == "TRUE"))) {
-    bdexpr <- bdexpr[[length(bdexpr)]]
-  }
-  is.call(bdexpr) && identical(bdexpr[[1L]], as.name("Linter"))
+  cli_abort(c(
+    i = "Expected {.fn {name}} to be a function of class {.cls linter}.",
+    x = "Instead, it is {.obj_type_friendly {linter}}."
+  ))
 }
 
 reorder_lints <- function(lints) {
@@ -397,24 +380,44 @@ reorder_lints <- function(lints) {
 #' @param message message used to describe the lint error
 #' @param line code source where the lint occurred
 #' @param ranges a list of ranges on the line that should be emphasized.
-#' @param linter deprecated. No longer used.
 #' @return an object of class `c("lint", "list")`.
 #' @name lint-s3
 #' @export
 Lint <- function(filename, line_number = 1L, column_number = 1L, # nolint: object_name.
                  type = c("style", "warning", "error"),
-                 message = "", line = "", ranges = NULL, linter = "") {
-  if (!missing(linter)) {
-    lintr_deprecated(
-      what = "Using the `linter` argument of `Lint()`",
-      version = "3.0.0",
-      type = "",
-      signal = "stop"
-    )
-  }
+                 message = "", line = "", ranges = NULL) {
+  validate_lint_object(message, line, line_number, column_number, ranges)
 
+  type <- match.arg(type)
+
+  obj <- list(
+    filename = filename,
+    line_number = as.integer(line_number),
+    column_number = as.integer(column_number),
+    type = type,
+    message = message,
+    line = line,
+    ranges = ranges,
+    linter = NA_character_
+  )
+  class(obj) <- c("lint", "list")
+  obj
+}
+
+# nolint next: cyclocomp_linter. Sequence of checks + early returns.
+validate_lint_object <- function(message, line, line_number, column_number, ranges) {
+  if (length(message) != 1L || !is.character(message)) {
+    cli_abort("{.arg message} must be a character string")
+  }
+  if (is.object(message)) {
+    cli_warn(c(
+      "{.arg message} must be a simple string, but has class {.cls {class(message)}}",
+      i = "This will be an error in the next lintr release"
+    ))
+    message <- unclass(message)
+  }
   if (length(line) != 1L || !is.character(line)) {
-    cli_abort("{.arg line} must be a string.", call. = FALSE)
+    cli_abort("{.arg line} must be a character string.")
   }
   max_col <- max(nchar(line) + 1L, 1L, na.rm = TRUE)
   if (!is_number(column_number) || column_number < 0L || column_number > max_col) {
@@ -427,21 +430,7 @@ Lint <- function(filename, line_number = 1L, column_number = 1L, # nolint: objec
     cli_abort("{.arg line_number} must be a positive integer, not {.obj_type_friendly {line_number}}.")
   }
   check_ranges(ranges, max_col)
-
-  type <- match.arg(type)
-
-  obj <- list(
-    filename = filename,
-    line_number = as.integer(line_number),
-    column_number = as.integer(column_number),
-    type = type,
-    message = message, # nolint: undesirable_function_linter
-    line = line,
-    ranges = ranges,
-    linter = NA_character_
-  )
-  class(obj) <- c("lint", "list")
-  obj
+  invisible()
 }
 
 is_number <- function(number, n = 1L) {
@@ -671,6 +660,73 @@ sarif_output <- function(lints, filename = "lintr_results.sarif") {
   write(jsonlite::toJSON(sarif, pretty = TRUE, auto_unbox = TRUE), filename)
 }
 
+#' GitLab Report for lint results
+#'
+#' Generate a report of the linting results using the
+#' [GitLab](https://docs.gitlab.com/ci/testing/code_quality/#code-quality-report-format) format.
+#'
+#' @details
+#' lintr only supports three severity types ("style", "warning", and "error")
+#' while the GitLab format supports five ("info", "minor", "major", "critical",
+#' and "blocker"). The types "style", "warning", and "error" are mapped to
+#' the GitLab types "info", "major", and "blocker", respectively. The GitLab
+#' types "minor" and "critical" are ignored.
+#'
+#' @param lints The linting results
+#' @param filename The file name of the output report
+#' @export
+gitlab_output <- function(lints, filename = "lintr_results.json") {
+  stopifnot(inherits(lints, "lints"))
+  if (!requireNamespace("jsonlite", quietly = TRUE)) {
+    cli_abort("{.pkg jsonlite} is required to produce Gitlab reports. Please install to continue.") # nocov
+  }
+
+  # Format
+  # (copied from https://docs.gitlab.com/ci/testing/code_quality/#code-quality-report-format)
+  # ==============================
+  # description          String   A human-readable description of the code quality violation.
+  # check_name           String   A unique name representing the check, or rule, associated with this violation.
+  # fingerprint          String   A unique fingerprint to identify this specific code quality violation, such as a hash
+  #                               of its contents.
+  # location.path        String   The file containing the code quality violation, expressed as a relative path in the
+  #                               repository. Do not prefix with ./.
+  # location.lines.begin
+  # -or-                 Integer  The line on which the code quality violation occurred.
+  # location.positions.begin.line
+  #
+  # severity             String   The severity of the violation, can be one of info, minor, major, critical, or blocker.
+
+  # Gitlab format as R data structure
+  res <-
+    lapply(
+      lints,
+      function(lint) {
+        with(
+          lint,
+          list(
+            description = message,
+            check_name = linter,
+            fingerprint =  digest::digest(line, algo = "sha1"),
+            location = list(
+              path = filename,
+              lines = list(
+                begin = line_number
+              )
+            ),
+            severity = switch(type,
+              style = "info",
+              error = "blocker",
+              warning = "major",
+              "info"
+            )
+          )
+        )
+      }
+    )
+
+  write(jsonlite::toJSON(res, pretty = TRUE, auto_unbox = TRUE), filename)
+}
+
 highlight_string <- function(message, column_number = NULL, ranges = NULL) {
   maximum <- max(column_number, unlist(ranges))
 
@@ -689,13 +745,8 @@ fill_with <- function(character = " ", length = 1L) {
   paste(collapse = "", rep.int(character, length))
 }
 
-has_positional_logical <- function(dots) {
-  length(dots) > 0L &&
-    is.logical(dots[[1L]]) &&
-    !nzchar(names2(dots)[1L])
-}
-
-maybe_append_error_lint <- function(lints, error, lint_cache, filename) {
+maybe_append_condition_lints <- function(lints, source_expression, lint_cache, filename) {
+  error <- source_expression$error
   if (is_lint(error)) {
     error$linter <- "error"
     lints[[length(lints) + 1L]] <- error
@@ -704,6 +755,14 @@ maybe_append_error_lint <- function(lints, error, lint_cache, filename) {
       cache_lint(lint_cache, list(filename = filename, content = ""), "error", error)
     }
   }
+  for (l in source_expression$warning) {
+    l$linter <- "parser_warning_linter"
+    lints[[length(lints) + 1L]] <- l
+
+    if (!is.null(lint_cache)) {
+      cache_lint(lint_cache, list(filename = filename, content = ""), "parser_warning_linter", l)
+    }
+  }
   lints
 }
 
@@ -725,3 +784,11 @@ zap_temp_filename <- function(res, needs_tempfile) {
   }
   res
 }
+
+necessary_linters <- function(expr, expression_linter_names, file_linter_names) {
+  if (is_lint_level(expr, "expression")) {
+    expression_linter_names
+  } else {
+    file_linter_names
+  }
+}
