@@ -8,14 +8,7 @@
 #' of `parsed_content`.
 #' @return `with_id`: A data frame corresponding to the row(s) specified in `id`.
 #' @export
-with_id <- function(source_expression, id, source_file) {
-  if (!missing(source_file)) {
-    lintr_deprecated(
-      what = "source_file", alternative = "source_expression", version = "3.0.0",
-      type = "Argument",
-      signal = "stop"
-    )
-  }
+with_id <- function(source_expression, id) {
   if (!is_lint_level(source_expression, "expression")) {
     return(data.frame())
   }
