@@ -9,6 +9,7 @@ with_content_to_parse <- function(content, code) {
   content_env <- new.env()
   content_env$pc <- lapply(source_expressions[["expressions"]], `[[`, "parsed_content")
   content_env$error <- source_expressions$error
+  content_env$warning <- source_expressions$warning
   eval(substitute(code), envir = content_env)
 }
 
@@ -104,16 +105,18 @@ test_that("Multi-byte character truncated by parser is ignored", {
 })
 
 test_that("Can read non UTF-8 file", {
-  file <- test_path("dummy_projects", "project", "cp1252.R")
-  lintr:::read_settings(file)
-  expect_null(get_source_expressions(file)$error)
+  withr::local_options(list(lintr.linter_file = tempfile()))
+  proj_dir <- test_path("dummy_projects", "project")
+  withr::local_dir(proj_dir)
+  expect_no_lint( # nofuzz
+    file = "cp1252.R",
+    linters = list()
+  )
 })
 
-test_that("Warns if encoding is misspecified", {
-  file <- test_path("dummy_projects", "project", "cp1252.R")
-  lintr:::read_settings(NULL)
-  the_lint <- lint(filename = file, parse_settings = FALSE)[[1L]]
-  expect_s3_class(the_lint, "lint")
+test_that("Warns if encoding is misspecified, Pt. 1", {
+  proj_dir <- test_path("dummy_projects", "project")
+  withr::local_dir(proj_dir)
 
   lint_msg <- "Invalid multibyte character in parser. Is the encoding correct?"
   if (!isTRUE(l10n_info()[["UTF-8"]])) {
@@ -123,23 +126,24 @@ test_that("Warns if encoding is misspecified", {
     lint_msg <- "unexpected '<'"
   }
 
-  expect_identical(the_lint$linter, "error")
-  expect_identical(the_lint$message, lint_msg)
-  expect_identical(the_lint$line_number, 4L)
+  expect_lint(
+    file = "cp1252.R",
+    parse_settings = FALSE,
+    checks = list(rex::rex(lint_msg), linter = "error", line_number = 4L)
+  )
 
-  file <- test_path("dummy_projects", "project", "cp1252_parseable.R")
-  lintr:::read_settings(NULL)
-  the_lint <- lint(filename = file, parse_settings = FALSE)[[1L]]
-  expect_s3_class(the_lint, "lint")
-  expect_identical(the_lint$linter, "error")
-  expect_identical(the_lint$message, "Invalid multibyte string. Is the encoding correct?")
-  expect_identical(the_lint$line_number, 1L)
+  expect_lint(
+    file = "cp1252_parseable.R",
+    parse_settings = FALSE,
+    checks = list(
+      rex::rex("Invalid multibyte string. Is the encoding correct?"),
+      linter = "error",
+      line_number = 1L
+    )
+  )
 })
 
 test_that("Can extract line number from parser errors", {
-  skip_if_not_r_version("4.0.0")
-
-  # malformed raw string literal at line 2
   with_content_to_parse(
     trim_some('
       "ok"
@@ -151,7 +155,6 @@ test_that("Can extract line number from parser errors", {
     }
   )
 
-  # invalid \u{xxxx} sequence (line 3)
   with_content_to_parse(
     trim_some('
       ok
@@ -164,7 +167,6 @@ test_that("Can extract line number from parser errors", {
     }
   )
 
-  # invalid \u{xxxx} sequence (line 4)
   with_content_to_parse(
     trim_some('
       ok
@@ -178,7 +180,6 @@ test_that("Can extract line number from parser errors", {
     }
   )
 
-  # repeated formal argument 'a' on line 1
   with_content_to_parse("function(a, a) {}", {
     expect_identical(error$message, "Repeated formal argument 'a'.")
     expect_identical(error$line_number, 1L)
@@ -217,7 +218,7 @@ test_that("returned data structure is complete", {
   attr(lines_with_attr, "terminal_newline") <- TRUE
 
   exprs <- get_source_expressions(temp_file)
-  expect_named(exprs, c("expressions", "error", "lines"))
+  expect_named(exprs, c("expressions", "error", "warning", "lines"))
   expect_length(exprs$expressions, length(lines) + 1L)
 
   for (i in seq_along(lines)) {
@@ -254,7 +255,14 @@ test_that("returned data structure is complete", {
 })
 
 test_that("xml_find_function_calls works as intended", {
-  lines <- c("foo()", "bar()", "foo()", "{ foo(); foo(); bar() }")
+  lines <- c(
+    "foo()",
+    "bar()",
+    "foo()",
+    "s4Obj@baz()",
+    "{ foo(); foo(); bar(); s4Obj@baz() }",
+    NULL
+  )
   temp_file <- withr::local_tempfile(lines = lines)
 
   exprs <- get_source_expressions(temp_file)
@@ -269,30 +277,40 @@ test_that("xml_find_function_calls works as intended", {
   expect_length(exprs$expressions[[2L]]$xml_find_function_calls("foo"), 0L)
   expect_length(exprs$expressions[[2L]]$xml_find_function_calls("bar"), 1L)
 
-  expect_length(exprs$expressions[[4L]]$xml_find_function_calls("foo"), 2L)
-  expect_length(exprs$expressions[[4L]]$xml_find_function_calls("bar"), 1L)
-  expect_length(exprs$expressions[[4L]]$xml_find_function_calls(c("foo", "bar")), 3L)
+  expect_length(exprs$expressions[[5L]]$xml_find_function_calls("foo"), 2L)
+  expect_length(exprs$expressions[[5L]]$xml_find_function_calls("bar"), 1L)
+  expect_length(exprs$expressions[[5L]]$xml_find_function_calls(c("foo", "bar")), 3L)
 
   # file-level source expression contains all function calls
-  expect_length(exprs$expressions[[5L]]$xml_find_function_calls("foo"), 4L)
-  expect_length(exprs$expressions[[5L]]$xml_find_function_calls("bar"), 2L)
-  expect_length(exprs$expressions[[5L]]$xml_find_function_calls(c("foo", "bar")), 6L)
+  expect_length(exprs$expressions[[6L]]$xml_find_function_calls("foo"), 4L)
+  expect_length(exprs$expressions[[6L]]$xml_find_function_calls("bar"), 2L)
+  expect_length(exprs$expressions[[6L]]$xml_find_function_calls(c("foo", "bar")), 6L)
 
   # Also check order is retained:
   expect_identical(
-    exprs$expressions[[5L]]$xml_find_function_calls(c("foo", "bar")),
-    xml_find_all(exprs$expressions[[5L]]$full_xml_parsed_content, "//SYMBOL_FUNCTION_CALL/parent::expr")
+    exprs$expressions[[6L]]$xml_find_function_calls(c("foo", "bar")),
+    xml_find_all(exprs$expressions[[6L]]$full_xml_parsed_content, "//SYMBOL_FUNCTION_CALL/parent::expr")
   )
 
   # Check naming and full cache
   expect_identical(
-    exprs$expressions[[5L]]$xml_find_function_calls(NULL),
-    exprs$expressions[[5L]]$xml_find_function_calls(c("foo", "bar"))
+    exprs$expressions[[6L]]$xml_find_function_calls(NULL),
+    exprs$expressions[[6L]]$xml_find_function_calls(c("foo", "bar"))
   )
   expect_named(
-    exprs$expressions[[4L]]$xml_find_function_calls(c("foo", "bar"), keep_names = TRUE),
+    exprs$expressions[[5L]]$xml_find_function_calls(c("foo", "bar"), keep_names = TRUE),
     c("foo", "foo", "bar")
   )
+
+  # include_s4_slots
+  expect_identical(
+    exprs$expressions[[6L]]$xml_find_function_calls(NULL, include_s4_slots = TRUE),
+    exprs$expressions[[6L]]$xml_find_function_calls(c("foo", "bar", "baz"), include_s4_slots = TRUE)
+  )
+  expect_named(
+    exprs$expressions[[5L]]$xml_find_function_calls(NULL, keep_names = TRUE, include_s4_slots = TRUE),
+    c("foo", "foo", "bar", "baz")
+  )
 })
 
 test_that("#1262: xml_parsed_content gets returned as missing even if there's no parsed_content", {
@@ -457,3 +475,90 @@ test_that("Disallowed embedded null gives parser failure lint", {
     linters = list()
   )
 })
+
+test_that("parser warnings are captured in output", {
+  with_content_to_parse("1e-3L", {
+    expect_length(warning, 1L)
+    expect_s3_class(warning, "lints")
+  })
+  with_content_to_parse("1e-3L; 1e-3L", {
+    expect_length(warning, 2L)
+  })
+  with_content_to_parse("1e-3L; 1.0L; 1.1L", {
+    expect_length(warning, 3L)
+  })
+  with_content_to_parse("1e-3L\n1.0L\n1.1L", {
+    expect_length(warning, 3L)
+  })
+  with_content_to_parse("1e-3L\n1+1\n1.0L\n2+2\n1.1L", {
+    expect_length(warning, 3L)
+  })
+  with_content_to_parse("1e-3L\nc(", {
+    expect_length(warning, 1L)
+    expect_length(error, 8L)
+  })
+})
+
+test_that("parser warnings generate lints", {
+  expect_lint(
+    "1e-3L",
+    "non-integer value 1e-3L",
+    linters = list()
+  )
+  expect_lint(
+    "1e-3L; 1e-3L",
+    list(
+      list("non-integer value 1e-3L", column_number = 1L),
+      list("non-integer value 1e-3L", column_number = 8L)
+    ),
+    linters = list()
+  )
+  expect_lint(
+    "1e-3L; 1.0L",
+    list(
+      list("non-integer value 1e-3L", column_number = 1L),
+      list("integer literal 1\\.0L", column_number = 8L)
+    ),
+    linters = list()
+  )
+  expect_lint(
+    trim_some("
+      1e-3L
+      1 + 1
+      1.0L
+      2 + 2
+      1.1L
+      3 + 3
+      2.2L
+      4 + 4
+      2.0L
+      5 + 5
+      2e-3L
+      # don't match strictly on regex, use parse tree
+      # 3.0L
+      # 3e-3L
+      # 3.3L
+      '4.0L'
+      '4e-3L'
+      '4.4L'
+    "),
+    list(
+      list("non-integer value 1e-3L", line_number = 1L),
+      list("integer literal 1\\.0L", line_number = 3L),
+      list("integer literal 1.1L contains decimal", line_number = 5L),
+      list("integer literal 2\\.2L contains decimal", line_number = 7L),
+      list("integer literal 2\\.0L", line_number = 9L),
+      list("non-integer value 2e-3L", line_number = 11L)
+    ),
+    linters = list()
+  )
+  # parser catches warning before erroring
+  expect_lint(
+    "1e-3L; c(",
+    list(
+      list("non-integer value 1e-3L", type = "warning"),
+      list("unexpected end of input", type = "error")
+    ),
+    linters = list()
+  )
+})
